@@ -878,6 +878,7 @@ class Trait(str, Enum):
     valkyrie = "valkyrie"
     immuneToPigify = "immuneToPigify"
     summerModeServant = "summerModeServant"
+    shinsengumiServant = "shinsengumiServant"
 
 
 TRAIT_NAME: dict[int, Trait] = {
@@ -1039,6 +1040,7 @@ TRAIT_NAME: dict[int, Trait] = {
     2836: Trait.protoMerlinNPChargeBlock,
     2837: Trait.valkyrie,
     2838: Trait.summerModeServant,
+    2839: Trait.shinsengumiServant,
     # 2xxx: CQ or Story quests buff
     3000: Trait.attackPhysical,  # Normal attack, including NP
     3001: Trait.attackProjectile,
